@@ -21,7 +21,7 @@ test_that("makeProgressBar", {
   bar(0.2)
   bar = makeProgressBar(max=10^6, label="          ")
   for(i in 10^seq(1:6)) {
-    bar(i, sprintf("%i", i))
+    bar(i, msg=sprintf("%i", i))
     Sys.sleep(0.1)
   }
 })
\ No newline at end of file
